<?php


/**
 * Vedic Rishi Client for consuming Vedic Rishi Astro Web APIs
 * http://www.vedicrishiastro.com/astro-api/
 * Author: Chandan Tiwari
 * Date: 06/12/14
 * Time: 5:42 PM
 */

class VedicRishiClient
{
    private $userId = null;
    private $apiKey = null;
    private $language = null;
    //TODO: MUST enable this on production- MUST
    //private $apiEndPoint = "https://api.vedicrishiastro.com/v1";
    //TODO: MUST- comment this and uncomment https url above on production for added security
    private $apiEndPoint = "https://api.vedicrishiastro.com/v1";
    /**
     * @param $uid string userId for Vedic Rishi Astro API
     * @param $key string api key for Vedic Rishi Astro API access
     */
    public function __construct($uid, $key)
    {
        $this->userId = $uid;
        $this->apiKey = $key;
    }

    /*
        A Function to set the Language of Response.
        Just call this function and you can change the language.
        This function should be passed either 'en' for English or 'hi' for Hindi.
    */
    public function setLanguage( $language )
    {
        $this->language = $language;
    }
    private function getCurlReponse($resource, array $data)
    {
        $serviceUrl = $this->apiEndPoint.'/'.$resource.'/';
        $authData = $this->userId.":".$this->apiKey;
        $ch = curl_init();
        curl_setopt($ch,CURLOPT_URL, $serviceUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 20);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
        $header[] = 'Authorization: Basic '. base64_encode($authData);

        /* Setting the Language of Response */
        if( $this->language != NULL ) {
            array_push( $header , 'Accept-Language: ' . $this->language );
        }
        curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($data));
        $response = curl_exec($ch);
        curl_close($ch);
        return $response;
    }
    private function packageHoroData($date, $month, $year, $hour, $minute,$seconds, $latitude, $longitude, $timezone,$ayanamsha)
    {
        return array(
            'day' => $date,
            'month' => $month,
            'year' => $year,
            'hour' => $hour,
            'min' => $minute,
            'seconds' => $seconds,
            'lat' => $latitude,
            'lon' => $longitude,
            'tzone' => $timezone,
            'ayanamsha' => $ayanamsha
        );
    }

    private function packageNumeroData($date, $month, $year, $name)
    {
        return array(
            'day' => $date,
            'month' => $month,
            'year' => $year,
            'name' => $name
        );
    }

    private function packageMatchMakingData($maleBirthData, $femaleBirthData)

    {

        $mData = array(

            'm_day' => $maleBirthData[1],
            'm_month' => $maleBirthData[2],
            'm_year' => $maleBirthData[3],
            'm_hour' => $maleBirthData[4],
            'm_min' => $maleBirthData[5],
            'm_lat' => $maleBirthData[6],
            'm_lon' => $maleBirthData[7],
            'm_tzone' => $maleBirthData[8]
        );
        $fData = array(
            'f_day' => $femaleBirthData[0],
            'f_month' => $femaleBirthData[1],
            'f_year' => $femaleBirthData[2],
            'f_hour' => $femaleBirthData[3],
            'f_min' => $femaleBirthData[4],
            'f_lat' => $femaleBirthData[5],
            'f_lon' => $femaleBirthData[6],
            'f_tzone' => $femaleBirthData[7]
        );

        return array_merge($mData, $fData);
    }

    private function packagePanchangData($date, $month, $year, $latitude, $longitude, $timezone)
    {
        return array(
            'day' => $date,
            'month' => $month,
            'year' => $year,
            'lat' => $latitude,
            'lon' => $longitude,
            'tzone' => $timezone,
            'name' => 'chandan'
        );
    }

    private function dataSanityCheck($data)
    {
    }
    /**
     * @param $resourceName string apiName name of an api without any begining and end slashes (ex 'birth_details')
     * @param $date date
     * @param $month month
     * @param $year year
     * @param $hour hour
     * @param $minute minute
     * @param $latitude latitude
     * @param $longitude longitude
     * @param $timezone timezone
     * @return array response data decoded in PHP associative array format
     */
    public function call($resourceName, $date, $month, $year, $hour, $minute,$seconds, $latitude, $longitude, $timezone,$ayanamsha)
    {
        $data = $this->packageHoroData($date, $month, $year, $hour, $minute,$seconds, $latitude, $longitude, $timezone,$ayanamsha);
        $resData = $this->getCurlReponse($resourceName, $data);
        return $resData;
    }
    /**
     * @param $resourceName string apiName name of numerological api (numero_table and numero_report)
     * @param $date int date of birth
     * @param $month int month of birth
     * @param $year int year of birth
     * @param $name string name
     * @return array response data decoded in PHP associative array format
     */
    public function numeroCall($resourceName, $date, $month, $year, $name)
    {
        $data = $this->packageNumeroData($date, $month, $year, $name);
        $resData = $this->getCurlReponse($resourceName, $data);
        return $resData;
    }
    /**
     * @param $resourceName apiName name of an api along without any begining and end slashes (ex match_birth_details)
     * @param array $maleBirthData  array maleBirthdata associative array format
     * @param array $femaleBirthData array femaleBirthdata associative array format
     * @return array response data decoded in PHP associative array format
     */
    public function matchMakingCall($resourceName, array $maleBirthData, array $femaleBirthData)
    {
        //TODO:  needs to validate male and female birth data against expected keys
        //$this->dataSanityCheck($maleBirthData);
        //$this->dataSanityCheck($femaleBirthData);
        $data = $this->packageMatchMakingData($maleBirthData, $femaleBirthData);
        $response = $this->getCurlReponse($resourceName, $data);
        return $response;
    }


    public function panchangCall($resourceName, $date, $month,$year, $latitude, $longitude, $timezone)
    {
        $data = $this->packagePanchangData($date, $month, $year, $latitude, $longitude, $timezone);
        $resData = $this->getCurlReponse($resourceName, $data);
        return $resData;
    }

    public function sunSignCall($resourceName, $language)
    {
        $data = ['en'];
        $resData = $this->getCurlReponse($resourceName, $data);
        return $resData;
    }

    public function timezone($data,$resourceName)
    {
        $resData = $this->getCurlReponse($resourceName, $data);
        return $resData;
    }
}
